import { OracleApi } from './OracleApi';
/**
 * Connects to the core services endpoints.
 */
export declare class CoreApi extends OracleApi {
    /**
     * Returns a boot volume from the API.
     * @param {string} bootVolumeId The boot volume id.
     * @return {Promise}
     */
    getBootVolume(bootVolumeId: string): Promise<{}>;
    /**
     * Connects to the get image endpoint.
     * @param {string} imageId The id of a specific image.
     * @return {Promise}
     */
    getImage(imageId: string): Promise<{}>;
    /**
     * Connects to the get instance endpoint.
     * @param {string} instanceId The ID of the specific instance.
     * @return {Promise}
     */
    getInstance(instanceId: string): Promise<{}>;
    /**
     * The get Volume endpoint.
     * @param {string} volumeId The id of the specific Volume.
     * @return {Promise}
     */
    getVolume(volumeId: string): Promise<{}>;
    /**
     * Calls the listBootVolume endpoint.
     * @param {string} compartmentId The id of the compartment.
     * @return {Promsie}
     */
    listBootVolume(compartmentId: string): Promise<{}>;
    /**
     * Calls the listBootVolumeAttachments endpoint.
     * @param {string} availabilityDomain The availability domain.
     * @param {string} compartmentId The compartment id.
     * @param {string=} instanceId The id of the compute instance.
     * @param {number=} limit The number of items to return in a paginated call.
     * @param {page=} page The paginated page to retrieve.
     * @return {Promise}
     */
    listBootVolumeAttachments(availabilityDomain: string, compartmentId: string, instanceId?: string, limit?: number, page?: number): Promise<{}>;
    /**
     * Connects to the list endpoint.
     * @param {string} compartmentId The ID of the parent compartment.
     * @return {Promise}
     */
    listInstances(compartmentId: string): Promise<{}>;
    /**
     * Returns shapes from the API.
     * @param {string} compartmentId Of the specified compartment.
     * @return {Promise}
     */
    listShapes(compartmentId: string): Promise<{}>;
    /**
     * List the volumes.
     * @param {stirng} compartmentId The id of the specific compartment.
     * @return {Promise}
     */
    listVolumes(compartmentId: string): Promise<{}>;
    /**
     * List volume attachment endpoint.
     * @param {string} compartmentId The compartment id.
     * @param {string} instanceId The instance id.
     * @return {Promise}
     */
    listVolumeAttachments(compartmentId: string, instanceId?: string): Promise<{}>;
    /**
     * Returns a list of volume backups.
     * @param {string} compartmentId The compartment id of the backup.
     * @param {string=} volumeId The ID of a specific volume.
     * @return {Promise}
     */
    listVolumeBackups(compartmentId: string, volumeId?: string): Promise<{}>;
}
